@@ -12,7 +12,7 @@ except ImportError:
 from .core import reverse_dict
 from .delayed import to_task_dask
 from .highlevelgraph import HighLevelGraph
-from .optimization import SubgraphCallable
+from .optimization import SubgraphCallable, fuse
 from .utils import ensure_dict, homogeneous_deepmap, apply
 
 
@@ -157,6 +157,7 @@ class Blockwise(Mapping):
     new_axes: Dict
         New index dimensions that may have been created, and their extent
 
+
     See Also
     --------
     dask.blockwise.blockwise
@@ -183,6 +184,9 @@ class Blockwise(Mapping):
         self.concatenate = concatenate
         self.new_axes = new_axes or {}
 
+    def __repr__(self):
+        return "Blockwise<{} -> {}>".format(self.indices, self.output)
+
     @property
     def _dict(self):
         if hasattr(self, "_cached_dict"):
@@ -643,15 +647,14 @@ def rewrite_blockwise(inputs):
 
             # Bump new inputs up in list
             sub = {}
+            # Map from (id(key), inds or None) -> index in indices. Used to deduplicate indices.
+            index_map = {(id(k), inds): n for n, (k, inds) in enumerate(indices)}
             for i, index in enumerate(new_indices):
-                try:
-                    contains = index in indices
-                except (ValueError, TypeError):
-                    contains = False
-
-                if contains:  # use old inputs if available
-                    sub[blockwise_token(i)] = blockwise_token(indices.index(index))
+                id_key = (id(index[0]), index[1])
+                if id_key in index_map:  # use old inputs if available
+                    sub[blockwise_token(i)] = blockwise_token(index_map[id_key])
                 else:
+                    index_map[id_key] = len(indices)
                     sub[blockwise_token(i)] = blockwise_token(len(indices))
                     indices.append(index)
             new_dsk = subs(inputs[dep].dsk, sub)
@@ -659,8 +662,6 @@ def rewrite_blockwise(inputs):
             # indices.extend(new_indices)
             dsk.update(new_dsk)
 
-    indices = [(a, tuple(b) if isinstance(b, list) else b) for a, b in indices]
-
     # De-duplicate indices like [(a, ij), (b, i), (a, ij)] -> [(a, ij), (b, i)]
     # Make sure that we map everything else appropriately as we remove inputs
     new_indices = []
@@ -775,3 +776,59 @@ def broadcast_dimensions(argpairs, numblocks, sentinels=(1, (1,)), consolidate=N
         raise ValueError("Shapes do not align %s" % g)
 
     return toolz.valmap(toolz.first, g2)
+
+
+def fuse_roots(graph: HighLevelGraph, keys: list):
+    """
+    Fuse nearby layers if they don't have dependencies
+
+    Often Blockwise sections of the graph fill out all of the computation
+    except for the initial data access or data loading layers::
+
+      Large Blockwise Layer
+        |       |       |
+        X       Y       Z
+
+    This can be troublesome because X, Y, and Z tasks may be executed on
+    different machines, and then require communication to move around.
+
+    This optimization identifies this situation, lowers all of the graphs to
+    concrete dicts, and then calls ``fuse`` on them, with a width equal to the
+    number of layers like X, Y, and Z.
+
+    This is currently used within array and dataframe optimizations.
+
+    Parameters
+    ----------
+    graph: HighLevelGraph
+        The full graph of the computation
+    keys: list
+        The output keys of the comptuation, to be passed on to fuse
+
+    See Also
+    --------
+    Blockwise
+    fuse
+    """
+    layers = graph.layers.copy()
+    dependencies = graph.dependencies.copy()
+    dependents = reverse_dict(dependencies)
+
+    for name, layer in graph.layers.items():
+        deps = graph.dependencies[name]
+        if (
+            isinstance(layer, Blockwise)
+            and len(deps) > 1
+            and not any(dependencies[dep] for dep in deps)  # no need to fuse if 0 or 1
+            and all(len(dependents[dep]) == 1 for dep in deps)
+        ):
+            new = toolz.merge(layer, *[layers[dep] for dep in deps])
+            new, _ = fuse(new, keys, ave_width=len(deps))
+
+            for dep in deps:
+                del layers[dep]
+
+            layers[name] = new
+            dependencies[name] = set()
+
+    return HighLevelGraph(layers, dependencies)
