@@ -1,6 +1,5 @@
 import numpy as np
 import pandas as pd
-import pandas.util.testing as tm
 import pytest
 
 import os
@@ -9,10 +8,16 @@ import pathlib
 
 import dask
 import dask.dataframe as dd
+from dask.dataframe._compat import tm
 from dask.utils import tmpfile, tmpdir, dependency_depth
 from dask.dataframe.utils import assert_eq
 
 
+skip_pandas_rc = pytest.mark.xfail(
+    dd._compat.PANDAS_GT_100, reason="https://github.com/pandas-dev/pandas/issues/30962"
+)
+
+
 def test_to_hdf():
     pytest.importorskip("tables")
     df = pd.DataFrame(
@@ -44,6 +49,7 @@ def test_to_hdf():
         tm.assert_frame_equal(df, out[:])
 
 
+@skip_pandas_rc
 def test_to_hdf_multiple_nodes():
     pytest.importorskip("tables")
     df = pd.DataFrame(
@@ -124,6 +130,7 @@ def test_to_hdf_multiple_nodes():
             assert_eq(df16, out)
 
 
+@skip_pandas_rc
 def test_to_hdf_multiple_files():
     pytest.importorskip("tables")
     df = pd.DataFrame(
@@ -207,6 +214,7 @@ def test_to_hdf_multiple_files():
             assert_eq(df, out)
 
 
+@skip_pandas_rc
 def test_to_hdf_modes_multiple_nodes():
     pytest.importorskip("tables")
     df = pd.DataFrame(
@@ -255,6 +263,7 @@ def test_to_hdf_modes_multiple_nodes():
         assert_eq(df.append(df), out)
 
 
+@skip_pandas_rc
 def test_to_hdf_modes_multiple_files():
     pytest.importorskip("tables")
     df = pd.DataFrame(
@@ -367,6 +376,7 @@ def test_to_hdf_link_optimizations():
 
 
 @pytest.mark.slow
+@skip_pandas_rc
 def test_to_hdf_lock_delays():
     pytest.importorskip("tables")
     df16 = pd.DataFrame(
@@ -458,6 +468,7 @@ def test_to_hdf_exceptions():
 
 @pytest.mark.parametrize("scheduler", ["sync", "threads", "processes"])
 @pytest.mark.parametrize("npartitions", [1, 4, 10])
+@skip_pandas_rc
 def test_to_hdf_schedulers(scheduler, npartitions):
     pytest.importorskip("tables")
     df = pd.DataFrame(
@@ -609,6 +620,7 @@ def test_to_fmt_warns():
         (pd.Series([1, 2, 3, 4], name="a"), tm.assert_series_equal),
     ],
 )
+@skip_pandas_rc
 def test_read_hdf(data, compare):
     pytest.importorskip("tables")
     with tmpfile("h5") as fn:
@@ -644,6 +656,7 @@ def test_read_hdf(data, compare):
         compare(a.compute(), sorted_data)
 
 
+@skip_pandas_rc
 def test_read_hdf_multiply_open():
     """Test that we can read from a file that's already opened elsewhere in
     read-only mode."""
@@ -657,6 +670,7 @@ def test_read_hdf_multiply_open():
             dd.read_hdf(fn, "/data", chunksize=2, mode="r")
 
 
+@skip_pandas_rc
 def test_read_hdf_multiple():
     pytest.importorskip("tables")
     df = pd.DataFrame(
@@ -710,6 +724,7 @@ def test_read_hdf_multiple():
         assert_eq(a, r)
 
 
+@skip_pandas_rc
 def test_read_hdf_start_stop_values():
     pytest.importorskip("tables")
     df = pd.DataFrame(
@@ -718,19 +733,17 @@ def test_read_hdf_start_stop_values():
     with tmpfile("h5") as fn:
         df.to_hdf(fn, "/data", format="table")
 
-        with pytest.raises(ValueError) as e:
+        with pytest.raises(ValueError, match="number of rows"):
             dd.read_hdf(fn, "/data", stop=10)
-        assert "number of rows" in str(e)
 
-        with pytest.raises(ValueError) as e:
+        with pytest.raises(ValueError, match="is above or equal to"):
             dd.read_hdf(fn, "/data", start=10)
-        assert "is above or equal to" in str(e)
 
-        with pytest.raises(ValueError) as e:
+        with pytest.raises(ValueError, match="positive integer"):
             dd.read_hdf(fn, "/data", chunksize=-1)
-        assert "positive integer" in str(e)
 
 
+@skip_pandas_rc
 def test_hdf_globbing():
     pytest.importorskip("tables")
     df = pd.DataFrame(
@@ -768,6 +781,7 @@ def test_hdf_globbing():
             tm.assert_frame_equal(res.compute(), pd.concat([df] * 3))
 
 
+@skip_pandas_rc
 def test_hdf_file_list():
     pytest.importorskip("tables")
     df = pd.DataFrame(
@@ -784,19 +798,35 @@ def test_hdf_file_list():
             tm.assert_frame_equal(res.compute(), df)
 
 
-def test_hdf_pattern_pathlike():
+@skip_pandas_rc
+def test_read_hdf_pattern_pathlike():
     pytest.importorskip("tables")
     df = pd.DataFrame(
         {"x": ["a", "b", "c", "d"], "y": [1, 2, 3, 4]}, index=[1.0, 2.0, 3.0, 4.0]
     )
 
-    with tmpdir() as tdir:
-        df.to_hdf(os.path.join(tdir, "test.h5"), "dataframe", format="table")
-        path = pathlib.Path(tdir) / "test.h5"
+    with tmpfile("h5") as fn:
+        path = pathlib.Path(fn)
+        df.to_hdf(path, "dataframe", format="table")
         res = dd.read_hdf(path, "dataframe")
         assert_eq(res, df)
 
 
+def test_to_hdf_path_pathlike():
+    pytest.importorskip("tables")
+    df = pd.DataFrame(
+        {"x": ["a", "b", "c", "d"], "y": [1, 2, 3, 4]}, index=[1.0, 2.0, 3.0, 4.0]
+    )
+    ddf = dd.from_pandas(df, npartitions=3)
+
+    with tmpfile("h5") as fn:
+        path = pathlib.Path(fn)
+        ddf.to_hdf(path, "/data")
+        res = pd.read_hdf(path, "/data")
+        assert_eq(res, ddf)
+
+
+@skip_pandas_rc
 def test_read_hdf_doesnt_segfault():
     pytest.importorskip("tables")
     with tmpfile("h5") as fn:
